<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis84000DmaBaFactory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis84000DmaBaService
{
    protected $environment;
    protected $dmaFactory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis84000DmaBaFactory $dmaFactory, Fis91000ObrigacoesAcessoriasService $obrigacoesService,
                                    NewCode $newCode, Agendamento $agendamento )
    {
        $this->environment          = $environment;
        $this->dmaFactory           = $dmaFactory;
        $this->obrigacoesService    = $obrigacoesService;
        $this->newCode              = $newCode;
        $this->agendamento          = $agendamento;
    }

    /**
     * Função para criar o arquivo da exportação DMA-BA
     */
    private function createFileDmaBa($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $dmaBaData = $this->dmaFactory->getDmaBaData($params);

        if(isset($row['NRAGENDAMENTO']) && empty($dmaBaData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        };
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $dmaBaData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

    /**
     * Função para a exportação DMA-BA
     */
    public function exportarDmaBa($row) {
        // Valida os parâmetros associados.
        $this->validateDmaBa($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);

        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDEMPRESA'         => $row['CDEMPRESA'],
            'CDIMPOSTO'         => '00',
            'CDINSCESTA'        => $row['CDINSCESTA'],
            'DTINICIAL'         => $row['DTINICIAL'],
            'DTFINAL'           => $row['DTFINAL'],
            'LIVROMAG'          => $row['CDLIVROMAG'],
            'IDRETIFICADORA'    => $row['IDRETIFICADORA'],
            'BAIXAEMPRESA'      => $row['BAIXAEMPRESA'],
            'IDINSCUNICA'       => $row['IDINSCUNICA'],
            'CODINSPETORIA'     => $row['CODINSPETORIA'],
            'CDGRUPPROD'        => $row['CDGRUPPROD'],
            'CHECKINFOEST'      => $row['CHECKINFOEST'],
            "NRSEQARQMAG"       => $row["NRSEQARQMAG"],
        ];

        // Chama a procedure de exportação
        $this->dmaFactory->callDmaBaProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileDmaBa($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->dmaFactory->deleteDmaBaData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->dmaFactory->deleteDmaBaData($params);
            throw $e;
        }

    }

    /**
     * Função para validação dos dados informados para o DMA-BA
     */
    private function validateDmaBa($row) {
        if (isset($row['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se o campo 'Retificadora' possui algum vlr informado
            if(empty($row['IDRETIFICADORA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Retificadora deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Retificadora deve ser informado');
            }
            // Verifica se o campo 'Baixa da Empresa' possui algum vlr informado
            if(empty($row['BAIXAEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Baixa da Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Baixa da Empresa deve ser informado');
            }
            // Verifica se o campo 'Inscrição Única' possui algum vlr informado
            if(empty($row['IDINSCUNICA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Inscrição Única deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Inscrição Única deve ser informado');
            }
            // Verifica se o campo 'Código da Inspetoria' possui algum vlr informado
            if(empty($row['CODINSPETORIA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Código da Inspetoria deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Código da Inspetoria deve ser informado');
            }
            // Verifica se o campo 'Agrupamento de Produtos' possui algum vlr informado
            if(empty($row['CDGRUPPROD'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Agrupamento de Produtos deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Agrupamento de Produtos deve ser informado');
            }
            // Verifica se o campo 'Gerar Informações de Estoque' possui algum vlr informado
            if(empty($row['CHECKINFOEST'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Gerar Informações de Estoque deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Gerar Informações de Estoque deve ser informado');
            }
    
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            //$row['NRORG'] = $nrorg;
    
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
    
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                $this->mensagemError = $this->mensagemError.'<br />'.'Todos os mapas devem estar bloquados para a geração do arquivo.';
                $this->geraArquivo = false;
                //throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
        else {
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                throw new \Exception('Incrição Estadual deve ser informada');
            }
            // Verifica se o campo 'Retificadora' possui algum vlr informado
            if(empty($row['IDRETIFICADORA'])){
                throw new \Exception('Retificadora deve ser informada');
            }
            // Verifica se o campo 'Baixa da Empresa' possui algum vlr informado
            if(empty($row['BAIXAEMPRESA'])){
                throw new \Exception('Baixa da Empresa deve ser informada');
            }
            // Verifica se o campo 'Incrição Única' possui algum vlr informado
            if(empty($row['IDINSCUNICA'])){
                throw new \Exception('Incrição Única deve ser informada');
            }
            // Verifica se o campo 'Código da Inspetoria' possui algum vlr informado
            if(empty($row['CODINSPETORIA'])){
                throw new \Exception('Código da Inspetoria deve ser informado');
            }
            // Verifica se o campo 'Agrupamento de Produtos' possui algum vlr informado
            if(empty($row['CDGRUPPROD'])){
                throw new \Exception('Agrupamento de Produtos deve ser informado');
            }
            // Verifica se o campo 'Gerar Informações de Estoque' possui algum vlr informado
            if(empty($row['CHECKINFOEST'])){
                throw new \Exception('Gerar Informações de Estoque deve ser informado');
            }
        
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            $row['NRORG'] = $nrorg;
        
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
        
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
    }
    
    
    public function findAgendamento() {
        // Busca os parâmetros conforme empresa e nrorg.
        $agendamento = $this->dmaFactory->findAgendamento();

        return $agendamento;
    }
    
    public function saveAgendamento($row) {
        try {
            
            $row['CDTELA'] = 'FIS84000';
            
            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
            
            //var_dump($row);
            //throw new \Exception('ioioioioioi');
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $row["NRAGENDAMENTO"] = $this->newCode->getCodeByTableName('NRAGENDAMENTO', $row["NRORG"], 1, 10);
            }
            
            if($row['CDINSCESTA'] == 'T'){
                $arrayInscEsta = $this->dmaFactory->getInscEsta($row);
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value['CDINSCESTA'].'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } else if(is_array($row['CDINSCESTA']) == true){
                $arrayInscEsta = $row['CDINSCESTA'];
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value.'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } 
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $this->dmaFactory->insertAgendamento($row);
            } else {
                $this->dmaFactory->updateAgendamento($row);
                
                 $arquivos = $this->dmaFactory->getAgendamentoArquivo($row);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->dmaFactory->deleteAgendamentoArquivo($arquivo);
                }
                
                $idstatus = 'P';
                $this->dmaFactory->updateAgendamentoIdStatus($row, $idstatus);
                
            }
            
            $agendamento = $this->dmaFactory->getAgendamentoInsert($row);
            
            if($agendamento){
                
                $agendamento['NRORG'] = $row['NRORG'];
                $getConfigSMTP = $this->dmaFactory->getConfiguraSMTP($agendamento)[0];
                if(isset($row['__is_new']) && $row['__is_new'] == true){
                    $nomeJob = $row['CDTELA'].'_'.$row['NRAGENDAMENTO'];
                } else {
                    $nomeJob = $row['CDTELA'].'_'.str_pad($row['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                }
                $dataContabAuto = $row['DTAGENDAMENTO'];
                $sequencialJob = $row['NRAGENDAMENTO'];
                $nrorg = $row['NRORG'];
                $descricao = $row['CDTELA'].' - DMA (Bahia)'.'. Exportação das declarações Acessórias de forma automática na data de '.$row['DTAGENDAMENTO'];
                //Conferir caminho do diretorio do xampp
                $arqCallService = $getConfigSMTP['CALLSERVPATH'];//'C:\Teknisa\CallService.php';
                //$dirphp = str_replace('/','\',$DIRPHP);
                $dirphp = $getConfigSMTP['DIRPHP'];//'C:/xampp/php';
                $jenkinsPath = $getConfigSMTP['JENKINSPATH'];//'http://192.168.120.132:8080/';
                $execPath = '/execAgendamentoDmaBa';
                $periodicidade = $row['IDPERIAGEN'];
                $jenkinsCreateItem = $getConfigSMTP['JENKCREATITEM'];
                $this->agendamento->criaJob($nomeJob, $dataContabAuto, $sequencialJob, $nrorg, $descricao, $arqCallService, $dirphp, $jenkinsPath, $execPath, $periodicidade, $jenkinsCreateItem);
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    public function execAgendamento($row){
        try{
            $agendamento = $this->dmaFactory->findAgendamentoExec($row)[0];
            
            $findParamDeclAcess = $this->dmaFactory->findParamDeclAcess($agendamento);
            
            $agendamento['CDLIVROMAG']      = isset($findParamDeclAcess['CDLIVROMAG']) ? $findParamDeclAcess['CDLIVROMAG'] : null;
            $agendamento['IDRETIFICADORA']  = isset($findParamDeclAcess['IDRETIFICADORA']) ? $findParamDeclAcess['IDRETIFICADORA'] : null;
            $agendamento['BAIXAEMPRESA']    = isset($findParamDeclAcess['BAIXAEMPRESA']) ? $findParamDeclAcess['BAIXAEMPRESA'] : null;
            $agendamento['IDINSCUNICA']     = isset($findParamDeclAcess['IDINSCUNICA']) ? $findParamDeclAcess['IDINSCUNICA'] : null;
            $agendamento['CODINSPETORIA']   = isset($findParamDeclAcess['CODINSPETORIA']) ? $findParamDeclAcess['CODINSPETORIA'] : null;
            $agendamento['CDGRUPPROD']      = isset($findParamDeclAcess['CDGRUPPROD']) ? $findParamDeclAcess['CDGRUPPROD'] : null;
            $agendamento['CHECKINFOEST']    = isset($findParamDeclAcess['CHECKINFOEST']) ? $findParamDeclAcess['CHECKINFOEST'] : null;
            
            if($agendamento){
                $this->mensagemBody = '';
                
                $agendamento["NRORG"] = $row['NRORG'];
                
                $agendamento["DTEXECAGEND"] = $agendamento["DTATUAL"];
                
                $agendamento["DTREFINI"] = explode(' ', $agendamento["DTREFINI"])[0];
                
                //Necessário Fazer a verificação
                
                $agendamento['CDINSCESTAARRAY'] = $agendamento['CDINSCESTA'];
                $arrayInscEsta = explode('_',$agendamento['CDINSCESTAARRAY']);
                
                $getConfigSMTP = $this->dmaFactory->getConfiguraSMTP($agendamento)[0];
                $getContatos = $this->dmaFactory->getContatos($agendamento);
                
                $mail = new PHPMailer;
                $mail->CharSet = 'UTF-8';
                $mail->isSMTP();                        // Set mailer to use SMTP
                $mail->isHTML();
                $mail->Host = $getConfigSMTP['SERVIDORSMTP'];       // Specify main and backup SMTP servers
                $mail->SMTPAuth = true;                 // Enable SMTP authentication
                $mail->Username = $getConfigSMTP['LOGINSMTP'];    // SMTP username
                $mail->Password = $getConfigSMTP['SENHASMTP'];    // SMTP password
                $mail->From = $getConfigSMTP['LOGINSMTP'];
                $mail->FromName = 'ERP Pebbian';
                $mail->Subject = 'DMA (Bahia) de '.$agendamento['DTAGENDAMENTO'];
                // $mail->addAddress($cliente['DSEMAILCLIE']);
                // $mail->addAddress($vendedor['DSEMAILOPER']);
                
                foreach($getContatos as $contato){
                    $mail->addAddress($contato['EMAIL']);
                };
                
                $agendamento["NMEMPRESA"] = $this->dmaFactory->getNmEmpresa($agendamento)["NMEMPRESA"];
                        
                $this->mensagemBody = 'Caro cliente, '.'<br />'.'<br />';
                $this->mensagemBodySucess = 'Arquivo de DMA (Bahia) gerado com Sucesso!'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                $this->mensagemErrorBody = 'Erro ao gerar o arquivo de DMA (Bahia):'.'<br />'.'<br />'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                
                
                $contErro = 0;
                $contSucess = 0;
                
                foreach( $arrayInscEsta as $inscEsta ){
                    if(isset($inscEsta) && $inscEsta != ''){
                        
                       $this->geraArquivo = true;
                            
                        $dataName = str_replace('/', '', explode(' ', $agendamento["DTATUAL"])[0]);
                        $horaName = str_replace(':', '', explode(' ', $agendamento["DTATUAL"])[1]);
                        
                        if($agendamento['IDPERIAGEN'] == '0'){
                            $dtinicial = $agendamento["DTINICIAL"];
                            $dtfinal = $agendamento["DTFINAL"];
                        } 
                        else if($agendamento['IDPERIAGEN'] == '1'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        } 
                        else if($agendamento['IDPERIAGEN'] == '2'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        }
                        
                        $agendamento["DTINICIAL"] = $dtinicial;
                        $agendamento["DTFINAL"] = $dtfinal;
                        
                        $agendamento['CDINSCESTA'] = $inscEsta;
                        $agendamento["NMARQUIVO"] = $agendamento['CDTELA'].$agendamento['NRAGENDAMENTO'].'_'.$inscEsta.'_'.$dataName.$horaName;
                          
                        $fileName = $this->exportarDmaBa($agendamento);
                        
                        if($this->mensagemError == ''){
                            $this->mensagemBodySucess = $this->mensagemBodySucess
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA'];
                            ++$contSucess;
                            
                        } else {
                            $this->mensagemErrorBody = $this->mensagemErrorBody
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA']
                            .$this->mensagemError.'<br />'.'<br />';
                            ++$contErro;
                        }
                        
                        if($fileName){
                            $file = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName;
                            $agendamento["NMPATHARQ"] = $file ;
                            
                            $verifArq = $this->dmaFactory->verAgendamentoArquivo($agendamento);
                            
                            if(empty($verifArq)){
                                $agendamento["NRARQUIVO"] = $this->newCode->getCodeByTableName('NRARQUIVO', $agendamento["NRORG"], 1, 10);
                                $this->dmaFactory->insertAgendamentoArquivo($agendamento);
                            }
                        }
                
                    }
                }
                
                if(($contErro > 0) && ($contSucess > 0)){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'.'<br />'
                    .'---------------------------------------------------------------------'.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                } 
                else if($contErro > 0){
                    $mail->Body = $this->mensagemBody.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                else if($contSucess > 0){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                
                $idstatus = 'R';
                $this->dmaFactory->updateAgendamentoIdStatus($agendamento, $idstatus);
                
            }
        
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAgendamento($row){
        try {    
            
            $agendamento = $this->dmaFactory->getAgendamentoInsert($row)[0];
            
            
            if($agendamento){
                $nomeJob = $agendamento['CDTELA'].'_'.str_pad($agendamento['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                $getConfigSMTP = $this->dmaFactory->getConfiguraSMTP($agendamento)[0];
                
                $this->agendamento->apagaJob($nomeJob, null, $getConfigSMTP['JENKINSPATH'], $getConfigSMTP["CALLSERVPATH"]);
                
                $arquivos = $this->dmaFactory->getAgendamentoArquivo($agendamento);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->dmaFactory->deleteAgendamentoArquivo($arquivo);
                    $this->dmaFactory->deleteAgendamento($arquivo);
                    
                } else {
                    $this->dmaFactory->deleteAgendamento($agendamento);
                }
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
                
    }
 
    private function formataData($data) {
        if (!$data) {
            return null;
        }

        // Verifica se está com o formato de data-hora.
        if (strlen($data) == 19) {
            $data = DateUtil::truncateString($data);
        }
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
    
}